==> icecat-38.6.0-gnu1.tar.bz2: icecat-38.6.0/services/healthreport/healthreport-prefs.js <==
#filter substitution
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

pref("datareporting.healthreport.currentDaySubmissionFailureCount", 0);
pref("datareporting.healthreport.documentServerURI", "https://fhr.data.mozilla.com/");
pref("datareporting.healthreport.documentServerNamespace", "metrics");
pref("datareporting.healthreport.logging.consoleEnabled", true);
pref("datareporting.healthreport.logging.consoleLevel", "Warn");
pref("datareporting.healthreport.logging.dumpEnabled", false);
pref("datareporting.healthreport.logging.dumpLevel", "Debug");
pref("datareporting.healthreport.lastDataSubmissionFailureTime", "0");
pref("datareporting.healthreport.lastDataSubmissionRequestedTime", "0");
pref("datareporting.healthreport.lastDataSubmissionSuccessfulTime", "0");
pref("datareporting.healthreport.nextDataSubmissionTime", "0");
pref("datareporting.healthreport.pendingDeleteRemoteData", false);

// Health Report is enabled by default on all channels.
pref("datareporting.healthreport.uploadEnabled", true);

pref("datareporting.healthreport.service.enabled", true);
pref("datareporting.healthreport.service.loadDelayMsec", 10000);
pref("datareporting.healthreport.service.loadDelayFirstRunMsec", 60000);

pref("datareporting.healthreport.service.providerCategories",
#if MOZ_UPDATE_CHANNEL == release
    "healthreport-js-provider-default"
#elif MOZ_UPDATE_CHANNEL == default
    "healthreport-js-provider-default"
#else
    "healthreport-js-provider-default,healthreport-js-provider-@MOZ_UPDATE_CHANNEL@"
#endif
    );

pref("datareporting.healthreport.about.reportUrl",   "https://fhr.cdn.mozilla.net/%LOCALE%/");
pref("datareporting.healthreport.infoURL", "https://www.gnu.org/software/gnuzilla/");

==> icecat-45.5.1-gnu1.tar.bz2: icecat-45.5.1/services/healthreport/healthreport-prefs.js <==
#filter substitution
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

pref("datareporting.healthreport.currentDaySubmissionFailureCount", 0);
pref("datareporting.healthreport.documentServerURI", "https://fhr.data.mozilla.com/");
pref("datareporting.healthreport.documentServerNamespace", "metrics");
pref("datareporting.healthreport.logging.consoleEnabled", true);
pref("datareporting.healthreport.logging.consoleLevel", "Warn");
pref("datareporting.healthreport.logging.dumpEnabled", false);
pref("datareporting.healthreport.logging.dumpLevel", "Debug");
pref("datareporting.healthreport.lastDataSubmissionFailureTime", "0");
pref("datareporting.healthreport.lastDataSubmissionRequestedTime", "0");
pref("datareporting.healthreport.lastDataSubmissionSuccessfulTime", "0");
pref("datareporting.healthreport.nextDataSubmissionTime", "0");
pref("datareporting.healthreport.pendingDeleteRemoteData", false);

// Health Report is enabled by default on all channels.
pref("datareporting.healthreport.uploadEnabled", true);

pref("datareporting.healthreport.service.enabled", true);
pref("datareporting.healthreport.service.loadDelayMsec", 10000);
pref("datareporting.healthreport.service.loadDelayFirstRunMsec", 60000);

pref("datareporting.healthreport.service.providerCategories",
#if MOZ_UPDATE_CHANNEL == release
    "healthreport-js-provider-default"
#elif MOZ_UPDATE_CHANNEL == default
    "healthreport-js-provider-default"
#else
    "healthreport-js-provider-default,healthreport-js-provider-@MOZ_UPDATE_CHANNEL@"
#endif
    );

pref("datareporting.healthreport.about.reportUrl", "https://fhr.cdn.mozilla.net/%LOCALE%/v4/");
pref("datareporting.healthreport.about.reportUrlUnified", "https://fhr.cdn.mozilla.net/%LOCALE%/v4/");
pref("datareporting.healthreport.infoURL", "https://www.gnu.org/software/gnuzilla/");
